@@ -1,3 +1,4 @@
+from copy import deepcopy
 from enum import Enum
 from typing import Any, Dict, Generator, List, Optional, Tuple, Union
 
@@ -7,6 +8,9 @@ from typing_extensions import TypedDict
 from ids_validator.checks.abstract_checker import CheckResult
 from ids_validator.models.validator_parameters import ValidatorParameters
 
+# TDP only allows up to 50 nested fields in a given IDS
+MAXIMUM_NESTED_FIELDS = 50
+
 ESMappingProperties = Dict[str, Union[dict, str]]
 
 
@@ -136,7 +140,7 @@ def validate_path_exists_as_array_of_objects(
     if schema_object is None:
         return CheckResult.critical(
             f"elasticsearch.json nested field, {field_path},"
-            " not found in the IDS. Each defined nested field defined"
+            " not found in the IDS. Each nested field defined"
             " in elasticsearch.json must exist in the IDS."
         )
 
@@ -296,7 +300,7 @@ def validate_nonsearchable_fields(
     Returns:
         List of CheckResult or empty list
     """
-    if ESKeys.NON_SEARCHABLE not in es_document:
+    if ESKeys.NON_SEARCHABLE.value not in es_document:
         return []
 
     non_searchable_fields = es_document.get(ESKeys.NON_SEARCHABLE.value)
@@ -357,7 +361,7 @@ def validate_elasticsearch_json(
     Returns:
         list of CheckResult instances containing errors found
     """
-    es_document = validator_parameters.artifact.elasticsearch
+    es_document = deepcopy(validator_parameters.artifact.elasticsearch)
     if not es_document:
         return [
             CheckResult.critical(
@@ -370,6 +374,14 @@ def validate_elasticsearch_json(
         validator_parameters.artifact.elasticsearch
     )
 
+    if len(nested_fields) > MAXIMUM_NESTED_FIELDS:
+        errors.append(
+            CheckResult.critical(
+                message=f"elasticsearch.json contains {len(nested_fields)} nested fields which exceeds"
+                f" the maximum allowed of {MAXIMUM_NESTED_FIELDS}."
+            )
+        )
+
     if nested_fields:
         errors += list(
             filter(
