@@ -8,3 +8,7 @@ class MergeException(Exception):
 
 class UnknownFieldType(Exception):
     """Needed to catch particular merge Exception."""
+
+
+class InvalidColumn(Exception):
+    """Error to raise when a column does not conform to platform requirements"""
