@@ -49,6 +49,10 @@ class NodePath:
         """Use a `.` separator to represent the path as a single string."""
         return ".".join(self.parts)
 
+    @staticmethod
+    def from_str(path: str) -> "NodePath":
+        return NodePath(tuple(path.split(".")))
+
 
 class Node(UserDict):
     """Class that hold methods to work with a Node of the JSON Schema."""
@@ -247,10 +251,10 @@ class Node(UserDict):
     def _is_numeric_type(self):
         if isinstance(self.type_, list):
             type_ = sorted(self.type_)
-            if not (type_ in [sorted(["null", "integer"]), sorted(["null", "number"])]):
+            if type_ not in [sorted(["null", "integer"]), sorted(["null", "number"])]:
                 return False
 
-        elif not (self.type_ in ["number", "integer"]):
+        elif self.type_ not in ["number", "integer"]:
             return False
 
         return True
