@@ -1,10 +1,11 @@
 from pathlib import Path
-from typing import Optional
+from typing import Optional, Sequence
 
 from rich.console import Console
 
 from ids_validator import tdp_api
-from ids_validator.models.validator_parameters import IdsArtifact, ValidatorParameters
+from ids_validator.models.ids_artifact import IdsArtifact
+from ids_validator.models.validator_parameters import ValidatorParameters
 from ids_validator.validator import Validator, default_console
 
 
@@ -12,6 +13,7 @@ def validate_ids_from_artifacts(
     ids_artifact: IdsArtifact,
     previous_ids_artifact: Optional[IdsArtifact] = None,
     console: Console = default_console,
+    artifact_range: Optional[Sequence[IdsArtifact]] = None,
 ) -> bool:
     """Run IDS validator and print warnings / failures to console
 
@@ -27,6 +29,7 @@ def validate_ids_from_artifacts(
     parameters = ValidatorParameters(
         artifact=ids_artifact,
         previous_artifact=previous_ids_artifact,
+        artifact_range=artifact_range,
     )
 
     validator = Validator(parameters, console=console)
@@ -49,6 +52,7 @@ def validate_ids(
     ids_dir: Path,
     previous_ids_dir: Optional[Path] = None,
     console: Console = default_console,
+    artifact_range: Optional[Sequence[IdsArtifact]] = None,
 ) -> bool:
     """Run IDS validator and print warnings / failures to console
 
@@ -70,6 +74,7 @@ def validate_ids(
         ids_artifact=ids_artifact,
         previous_ids_artifact=previous_artifact,
         console=console,
+        artifact_range=artifact_range,
     )
 
 
@@ -100,8 +105,18 @@ def validate_ids_using_tdp_artifact(
         slug=ids_artifact.identity.slug,
         target_version=ids_artifact.identity.version,
     )
+
+    # For merge compatibility, use all versions from the same major version
+    artifact_range = tdp_api.get_artifacts_range(
+        config=api_config,
+        namespace=ids_artifact.identity.namespace,
+        slug=ids_artifact.identity.slug,
+        major_version=ids_artifact.identity.version_parts.major,
+    )
+
     return validate_ids_from_artifacts(
         ids_artifact=ids_artifact,
         previous_ids_artifact=previous_ids_artifact,
         console=console,
+        artifact_range=artifact_range,
     )
